summaryrefslogtreecommitdiffstats
path: root/filters/chalk
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /filters/chalk
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'filters/chalk')
-rw-r--r--filters/chalk/gmagick/magickexport.h2
-rw-r--r--filters/chalk/gmagick/magickimport.h2
-rw-r--r--filters/chalk/jpeg/kis_jpeg_export.h2
-rw-r--r--filters/chalk/jpeg/kis_jpeg_import.h2
-rw-r--r--filters/chalk/magick/magickexport.h2
-rw-r--r--filters/chalk/magick/magickimport.h2
-rw-r--r--filters/chalk/openexr/kis_openexr_export.h2
-rw-r--r--filters/chalk/openexr/kis_openexr_import.h2
-rw-r--r--filters/chalk/pdf/kis_pdf_import.h2
-rw-r--r--filters/chalk/pdf/kis_pdf_import_widget.cpp4
-rw-r--r--filters/chalk/pdf/kis_pdf_import_widget.h2
-rw-r--r--filters/chalk/png/kis_png_export.h2
-rw-r--r--filters/chalk/png/kis_png_import.h2
-rw-r--r--filters/chalk/raw/dcraw.c10
-rw-r--r--filters/chalk/raw/kis_raw_import.h2
-rw-r--r--filters/chalk/tiff/kis_dlg_options_tiff.cpp4
-rw-r--r--filters/chalk/tiff/kis_dlg_options_tiff.h2
-rw-r--r--filters/chalk/tiff/kis_tiff_export.h2
-rw-r--r--filters/chalk/tiff/kis_tiff_import.h2
-rw-r--r--filters/chalk/xcf/xcf/xcf-load.cc90
-rw-r--r--filters/chalk/xcf/xcf/xcf-save.cc40
-rw-r--r--filters/chalk/xcf/xcfexport.h2
-rw-r--r--filters/chalk/xcf/xcfimport.h2
23 files changed, 92 insertions, 92 deletions
diff --git a/filters/chalk/gmagick/magickexport.h b/filters/chalk/gmagick/magickexport.h
index 6ea7e238..46a080f4 100644
--- a/filters/chalk/gmagick/magickexport.h
+++ b/filters/chalk/gmagick/magickexport.h
@@ -26,7 +26,7 @@ class MagickExport : public KoFilter {
TQ_OBJECT
public:
- MagickExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ MagickExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~MagickExport();
public:
diff --git a/filters/chalk/gmagick/magickimport.h b/filters/chalk/gmagick/magickimport.h
index 3373f129..22bf3002 100644
--- a/filters/chalk/gmagick/magickimport.h
+++ b/filters/chalk/gmagick/magickimport.h
@@ -26,7 +26,7 @@ class MagickImport : public KoFilter {
TQ_OBJECT
public:
- MagickImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ MagickImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~MagickImport();
public:
diff --git a/filters/chalk/jpeg/kis_jpeg_export.h b/filters/chalk/jpeg/kis_jpeg_export.h
index a0f47351..ea55c12c 100644
--- a/filters/chalk/jpeg/kis_jpeg_export.h
+++ b/filters/chalk/jpeg/kis_jpeg_export.h
@@ -26,7 +26,7 @@ class KisJPEGExport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- KisJPEGExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisJPEGExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisJPEGExport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/jpeg/kis_jpeg_import.h b/filters/chalk/jpeg/kis_jpeg_import.h
index 4cfb62c2..a32c367f 100644
--- a/filters/chalk/jpeg/kis_jpeg_import.h
+++ b/filters/chalk/jpeg/kis_jpeg_import.h
@@ -25,7 +25,7 @@ class KisJPEGImport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- KisJPEGImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisJPEGImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisJPEGImport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/magick/magickexport.h b/filters/chalk/magick/magickexport.h
index 6ea7e238..46a080f4 100644
--- a/filters/chalk/magick/magickexport.h
+++ b/filters/chalk/magick/magickexport.h
@@ -26,7 +26,7 @@ class MagickExport : public KoFilter {
TQ_OBJECT
public:
- MagickExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ MagickExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~MagickExport();
public:
diff --git a/filters/chalk/magick/magickimport.h b/filters/chalk/magick/magickimport.h
index 3373f129..22bf3002 100644
--- a/filters/chalk/magick/magickimport.h
+++ b/filters/chalk/magick/magickimport.h
@@ -26,7 +26,7 @@ class MagickImport : public KoFilter {
TQ_OBJECT
public:
- MagickImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ MagickImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~MagickImport();
public:
diff --git a/filters/chalk/openexr/kis_openexr_export.h b/filters/chalk/openexr/kis_openexr_export.h
index 56568e57..7f0c71f9 100644
--- a/filters/chalk/openexr/kis_openexr_export.h
+++ b/filters/chalk/openexr/kis_openexr_export.h
@@ -27,7 +27,7 @@ class KisOpenEXRExport : public KoFilter {
TQ_OBJECT
public:
- KisOpenEXRExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisOpenEXRExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisOpenEXRExport();
public:
diff --git a/filters/chalk/openexr/kis_openexr_import.h b/filters/chalk/openexr/kis_openexr_import.h
index f8cd5144..8bddb4f5 100644
--- a/filters/chalk/openexr/kis_openexr_import.h
+++ b/filters/chalk/openexr/kis_openexr_import.h
@@ -27,7 +27,7 @@ class KisOpenEXRImport : public KoFilter {
TQ_OBJECT
public:
- KisOpenEXRImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisOpenEXRImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisOpenEXRImport();
public:
diff --git a/filters/chalk/pdf/kis_pdf_import.h b/filters/chalk/pdf/kis_pdf_import.h
index ab4535b9..06e22288 100644
--- a/filters/chalk/pdf/kis_pdf_import.h
+++ b/filters/chalk/pdf/kis_pdf_import.h
@@ -26,7 +26,7 @@ class KisPDFImport : public KoFilter{
Q_OBJECT
TQ_OBJECT
public:
- KisPDFImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisPDFImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisPDFImport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/pdf/kis_pdf_import_widget.cpp b/filters/chalk/pdf/kis_pdf_import_widget.cpp
index 6919876f..c395d9e9 100644
--- a/filters/chalk/pdf/kis_pdf_import_widget.cpp
+++ b/filters/chalk/pdf/kis_pdf_import_widget.cpp
@@ -30,8 +30,8 @@
#include <klistbox.h>
#include <knuminput.h>
-KisPDFImportWidget::KisPDFImportWidget(Poppler::Document* pdfDoc, TQWidget * tqparent, const char * name)
- : PDFImportWidgetBase(tqparent, name), m_pdfDoc(pdfDoc)
+KisPDFImportWidget::KisPDFImportWidget(Poppler::Document* pdfDoc, TQWidget * parent, const char * name)
+ : PDFImportWidgetBase(parent, name), m_pdfDoc(pdfDoc)
{
m_pages.push_back(0); // The first page is selected
updateMaxCanvasSize();
diff --git a/filters/chalk/pdf/kis_pdf_import_widget.h b/filters/chalk/pdf/kis_pdf_import_widget.h
index 8fe806a8..dc8900dd 100644
--- a/filters/chalk/pdf/kis_pdf_import_widget.h
+++ b/filters/chalk/pdf/kis_pdf_import_widget.h
@@ -31,7 +31,7 @@ class KisPDFImportWidget : public PDFImportWidgetBase
Q_OBJECT
TQ_OBJECT
public:
- KisPDFImportWidget(Poppler::Document* pdfDoc, TQWidget * tqparent, const char * name = "");
+ KisPDFImportWidget(Poppler::Document* pdfDoc, TQWidget * parent, const char * name = "");
~KisPDFImportWidget();
public:
diff --git a/filters/chalk/png/kis_png_export.h b/filters/chalk/png/kis_png_export.h
index d962523d..433b68e3 100644
--- a/filters/chalk/png/kis_png_export.h
+++ b/filters/chalk/png/kis_png_export.h
@@ -26,7 +26,7 @@ class KisPNGExport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- KisPNGExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisPNGExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisPNGExport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/png/kis_png_import.h b/filters/chalk/png/kis_png_import.h
index d0b8502a..3487d24d 100644
--- a/filters/chalk/png/kis_png_import.h
+++ b/filters/chalk/png/kis_png_import.h
@@ -25,7 +25,7 @@ class KisPNGImport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- KisPNGImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisPNGImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisPNGImport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/raw/dcraw.c b/filters/chalk/raw/dcraw.c
index e92c1d3c..b892a5ca 100644
--- a/filters/chalk/raw/dcraw.c
+++ b/filters/chalk/raw/dcraw.c
@@ -1146,12 +1146,12 @@ void CLASS rollei_load_raw()
void CLASS phase_one_load_raw()
{
int row, col, a, b;
- ushort *pixel, akey, bkey, tqmask;
+ ushort *pixel, akey, bkey, mask;
fseek (ifp, nikon_curve_offset, SEEK_SET);
akey = get2();
bkey = get2();
- tqmask = tiff_data_compression == 1 ? 0x5555:0x1354;
+ mask = tiff_data_compression == 1 ? 0x5555:0x1354;
fseek (ifp, data_offset + top_margin*raw_width*2, SEEK_SET);
pixel = calloc (raw_width, sizeof *pixel);
merror (pixel, "phase_one_load_raw()");
@@ -1160,8 +1160,8 @@ void CLASS phase_one_load_raw()
for (col=0; col < raw_width; col+=2) {
a = pixel[col+0] ^ akey;
b = pixel[col+1] ^ bkey;
- pixel[col+0] = (a & tqmask) | (b & ~tqmask);
- pixel[col+1] = (b & tqmask) | (a & ~tqmask);
+ pixel[col+0] = (a & mask) | (b & ~mask);
+ pixel[col+1] = (b & mask) | (a & ~mask);
}
for (col=0; col < width; col++)
BAYER(row,col) = pixel[col+left_margin];
@@ -5731,7 +5731,7 @@ void CLASS write_psd (FILE *ofp)
0,3, /* mode (1=grey, 3=rgb) */
0,0,0,0, /* color mode data */
0,0,0,0, /* image resources */
- 0,0,0,0, /* layer/tqmask info */
+ 0,0,0,0, /* layer/mask info */
0,0 /* no compression */
};
int hw[2], psize, row, col, c;
diff --git a/filters/chalk/raw/kis_raw_import.h b/filters/chalk/raw/kis_raw_import.h
index 35adb6e1..17fd576c 100644
--- a/filters/chalk/raw/kis_raw_import.h
+++ b/filters/chalk/raw/kis_raw_import.h
@@ -33,7 +33,7 @@ class KisRawImport : public KoFilter {
TQ_OBJECT
public:
- KisRawImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisRawImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisRawImport();
public:
diff --git a/filters/chalk/tiff/kis_dlg_options_tiff.cpp b/filters/chalk/tiff/kis_dlg_options_tiff.cpp
index 345f7e7e..7a6ad9ca 100644
--- a/filters/chalk/tiff/kis_dlg_options_tiff.cpp
+++ b/filters/chalk/tiff/kis_dlg_options_tiff.cpp
@@ -30,8 +30,8 @@
#include "kis_wdg_options_tiff.h"
-KisDlgOptionsTIFF::KisDlgOptionsTIFF(TQWidget *tqparent, const char *name)
- : KDialogBase(tqparent, name, false, i18n("TIFF Export Options"), KDialogBase::Ok | KDialogBase::Cancel)
+KisDlgOptionsTIFF::KisDlgOptionsTIFF(TQWidget *parent, const char *name)
+ : KDialogBase(parent, name, false, i18n("TIFF Export Options"), KDialogBase::Ok | KDialogBase::Cancel)
{
optionswdg = new KisWdgOptionsTIFF(this);
activated(0);
diff --git a/filters/chalk/tiff/kis_dlg_options_tiff.h b/filters/chalk/tiff/kis_dlg_options_tiff.h
index 5fd1e48e..519f2ceb 100644
--- a/filters/chalk/tiff/kis_dlg_options_tiff.h
+++ b/filters/chalk/tiff/kis_dlg_options_tiff.h
@@ -32,7 +32,7 @@ class KisDlgOptionsTIFF : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- KisDlgOptionsTIFF(TQWidget *tqparent=0, const char *name=0);
+ KisDlgOptionsTIFF(TQWidget *parent=0, const char *name=0);
~KisDlgOptionsTIFF();
public slots:
void activated ( int index );
diff --git a/filters/chalk/tiff/kis_tiff_export.h b/filters/chalk/tiff/kis_tiff_export.h
index 113747c7..9efeb940 100644
--- a/filters/chalk/tiff/kis_tiff_export.h
+++ b/filters/chalk/tiff/kis_tiff_export.h
@@ -26,7 +26,7 @@ class KisTIFFExport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- KisTIFFExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisTIFFExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisTIFFExport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/tiff/kis_tiff_import.h b/filters/chalk/tiff/kis_tiff_import.h
index 9fef7755..b9e33d06 100644
--- a/filters/chalk/tiff/kis_tiff_import.h
+++ b/filters/chalk/tiff/kis_tiff_import.h
@@ -25,7 +25,7 @@ class KisTIFFImport : public KoFilter {
Q_OBJECT
TQ_OBJECT
public:
- KisTIFFImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ KisTIFFImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KisTIFFImport();
public:
virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
diff --git a/filters/chalk/xcf/xcfexport.h b/filters/chalk/xcf/xcfexport.h
index b6acf737..b8f260fb 100644
--- a/filters/chalk/xcf/xcfexport.h
+++ b/filters/chalk/xcf/xcfexport.h
@@ -26,7 +26,7 @@ class XCFExport : public KoFilter {
TQ_OBJECT
public:
- XCFExport(KoFilter *tqparent, const char *name, const TQStringList&);
+ XCFExport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~XCFExport();
public:
diff --git a/filters/chalk/xcf/xcfimport.h b/filters/chalk/xcf/xcfimport.h
index 038e7604..434566ba 100644
--- a/filters/chalk/xcf/xcfimport.h
+++ b/filters/chalk/xcf/xcfimport.h
@@ -26,7 +26,7 @@ class XCFImport : public KoFilter {
TQ_OBJECT
public:
- XCFImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ XCFImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~XCFImport();
public:
diff --git a/filters/chalk/xcf/xcf/xcf-load.cc b/filters/chalk/xcf/xcf/xcf-load.cc
index 670bec0a..90d61755 100644
--- a/filters/chalk/xcf/xcf/xcf-load.cc
+++ b/filters/chalk/xcf/xcf/xcf-load.cc
@@ -43,7 +43,7 @@
//#include "core/gimpimage-guides.h"
//#include "core/gimplayer.h"
//#include "core/gimplayer-floating-sel.h"
-//#include "core/gimplayertqmask.h"
+//#include "core/gimplayermask.h"
//#include "core/gimpparasitelist.h"
//#include "core/gimpselection.h"
//#include "core/gimptemplate.h"
@@ -69,9 +69,9 @@ static bool xcf_load_image_props (XcfInfo * info, KisImage * gimage);
static bool xcf_load_layer_props (XcfInfo * info,
KisImage * gimage,
KisLayer * layer,
- bool * apply_tqmask,
- bool * edit_tqmask,
- bool * show_tqmask,
+ bool * apply_mask,
+ bool * edit_mask,
+ bool * show_mask,
TQ_INT32 * text_layer_flags);
static bool xcf_load_channel_props (XcfInfo * info,
KisImage * gimage,
@@ -81,7 +81,7 @@ static bool xcf_load_prop (XcfInfo * info,
static KisLayer *xcf_load_layer (XcfInfo * info, KisImage * gimage);
//static GimpChannel * xcf_load_channel (XcfInfo *info,
// KisImage *gimage);
-//static GimpLayerMask * xcf_load_layer_tqmask (XcfInfo *info,
+//static GimpLayerMask * xcf_load_layer_mask (XcfInfo *info,
// KisImage *gimage);
static bool xcf_load_hierarchy (XcfInfo * info, TileManager * tiles);
static bool xcf_load_level (XcfInfo * info, TileManager * tiles);
@@ -210,7 +210,7 @@ xcf_load_image (XcfInfo * info)
num_successful_elements++;
/* add the channel to the image if its not the selection */
- if (channel != gimage->selection_tqmask)
+ if (channel != gimage->selection_mask)
gimp_image_add_channel (gimage, channel, -1);
/* restore the saved position so we'll be ready to
@@ -547,9 +547,9 @@ static bool
xcf_load_layer_props (XcfInfo * info,
KisImage * gimage,
KisLayer * layer,
- bool * apply_tqmask,
- bool * edit_tqmask,
- bool * show_tqmask, TQ_INT32 * text_layer_flags)
+ bool * apply_mask,
+ bool * edit_mask,
+ bool * show_mask, TQ_INT32 * text_layer_flags)
{
PropType prop_type;
TQ_INT32 prop_size;
@@ -612,15 +612,15 @@ xcf_load_layer_props (XcfInfo * info,
break;
case PROP_APPLY_MASK:
- info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) apply_tqmask, 1);
+ info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) apply_mask, 1);
break;
case PROP_EDIT_MASK:
- info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) edit_tqmask, 1);
+ info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) edit_mask, 1);
break;
case PROP_SHOW_MASK:
- info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) show_tqmask, 1);
+ info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) show_mask, 1);
break;
case PROP_OFFSETS:
@@ -707,20 +707,20 @@ xcf_load_channel_props (XcfInfo * info,
break;
case PROP_SELECTION:
- g_object_unref (gimage->selection_tqmask);
- gimage->selection_tqmask =
+ g_object_unref (gimage->selection_mask);
+ gimage->selection_mask =
gimp_selection_new (gimage,
gimp_item_width (GIMP_ITEM (*channel)),
gimp_item_height (GIMP_ITEM (*channel)));
- g_object_ref (gimage->selection_tqmask);
- gimp_item_sink (GIMP_ITEM (gimage->selection_tqmask));
+ g_object_ref (gimage->selection_mask);
+ gimp_item_sink (GIMP_ITEM (gimage->selection_mask));
- tile_manager_unref (GIMP_DRAWABLE (gimage->selection_tqmask)->tiles);
- GIMP_DRAWABLE (gimage->selection_tqmask)->tiles =
+ tile_manager_unref (GIMP_DRAWABLE (gimage->selection_mask)->tiles);
+ GIMP_DRAWABLE (gimage->selection_mask)->tiles =
GIMP_DRAWABLE (*channel)->tiles;
GIMP_DRAWABLE (*channel)->tiles = NULL;
g_object_unref (*channel);
- *channel = gimage->selection_tqmask;
+ *channel = gimage->selection_mask;
(*channel)->boundary_known = FALSE;
(*channel)->bounds_known = FALSE;
break;
@@ -831,12 +831,12 @@ static KisLayer *
xcf_load_layer (XcfInfo * info, KisImage * gimage)
{
KisLayer *layer;
- GimpLayerMask *layer_tqmask;
+ GimpLayerMask *layer_mask;
TQ_INT32 hierarchy_offset;
TQ_INT32 layer_mask_offset;
- bool apply_tqmask = TRUE;
- bool edit_tqmask = FALSE;
- bool show_tqmask = FALSE;
+ bool apply_mask = TRUE;
+ bool edit_mask = FALSE;
+ bool show_mask = FALSE;
bool active;
bool floating;
TQ_INT32 text_layer_flags = 0;
@@ -866,7 +866,7 @@ xcf_load_layer (XcfInfo * info, KisImage * gimage)
/* read in the layer properties */
if (!xcf_load_layer_props (info, gimage, layer,
- &apply_tqmask, &edit_tqmask, &show_tqmask,
+ &apply_mask, &edit_mask, &show_mask,
&text_layer_flags))
goto error;
@@ -885,7 +885,7 @@ xcf_load_layer (XcfInfo * info, KisImage * gimage)
info->floating_sel = layer;
}
- /* read the hierarchy and layer tqmask offsets */
+ /* read the hierarchy and layer mask offsets */
info->cp += xcf_read_int32 (info->fp, &hierarchy_offset, 1);
info->cp += xcf_read_int32 (info->fp, &layer_mask_offset, 1);
@@ -896,21 +896,21 @@ xcf_load_layer (XcfInfo * info, KisImage * gimage)
if (!xcf_load_hierarchy (info, GIMP_DRAWABLE (layer)->tiles))
goto error;
- /* read in the layer tqmask */
+ /* read in the layer mask */
if (layer_mask_offset != 0)
{
if (!xcf_seek_pos (info, layer_mask_offset, NULL))
goto error;
- layer_tqmask = xcf_load_layer_tqmask (info, gimage);
- if (!layer_tqmask)
+ layer_mask = xcf_load_layer_mask (info, gimage);
+ if (!layer_mask)
goto error;
- layer_tqmask->apply_tqmask = apply_tqmask;
- layer_tqmask->edit_tqmask = edit_tqmask;
- layer_tqmask->show_tqmask = show_tqmask;
+ layer_mask->apply_mask = apply_mask;
+ layer_mask->edit_mask = edit_mask;
+ layer_mask->show_mask = show_mask;
- gimp_layer_add_tqmask (layer, layer_tqmask, FALSE);
+ gimp_layer_add_mask (layer, layer_mask, FALSE);
}
/* attach the floating selection... */
@@ -955,7 +955,7 @@ xcf_load_channel (XcfInfo * info, KisImage * gimage)
if (!xcf_load_channel_props (info, gimage, &channel))
goto error;
- /* read the hierarchy and layer tqmask offsets */
+ /* read the hierarchy and layer mask offsets */
info->cp += xcf_read_int32 (info->fp, &hierarchy_offset, 1);
/* read in the hierarchy */
@@ -976,9 +976,9 @@ error:
}
static GimpLayerMask *
-xcf_load_layer_tqmask (XcfInfo * info, KisImage * gimage)
+xcf_load_layer_mask (XcfInfo * info, KisImage * gimage)
{
- GimpLayerMask *layer_tqmask;
+ GimpLayerMask *layer_mask;
GimpChannel *channel;
TQ_INT32 hierarchy_offset;
TQ_INT32 width;
@@ -997,35 +997,35 @@ xcf_load_layer_tqmask (XcfInfo * info, KisImage * gimage)
info->cp += xcf_read_int32 (info->fp, (TQ_INT32 *) & height, 1);
info->cp += xcf_read_string (info->fp, &name, 1);
- /* create a new layer tqmask */
- layer_tqmask = gimp_layer_mask_new (gimage, width, height, name, &color);
+ /* create a new layer mask */
+ layer_mask = gimp_layer_mask_new (gimage, width, height, name, &color);
g_free (name);
- if (!layer_tqmask)
+ if (!layer_mask)
return NULL;
- /* read in the layer_tqmask properties */
- channel = GIMP_CHANNEL (layer_tqmask);
+ /* read in the layer_mask properties */
+ channel = GIMP_CHANNEL (layer_mask);
if (!xcf_load_channel_props (info, gimage, &channel))
goto error;
- /* read the hierarchy and layer tqmask offsets */
+ /* read the hierarchy and layer mask offsets */
info->cp += xcf_read_int32 (info->fp, &hierarchy_offset, 1);
/* read in the hierarchy */
if (!xcf_seek_pos (info, hierarchy_offset, NULL))
goto error;
- if (!xcf_load_hierarchy (info, GIMP_DRAWABLE (layer_tqmask)->tiles))
+ if (!xcf_load_hierarchy (info, GIMP_DRAWABLE (layer_mask)->tiles))
goto error;
/* attach the floating selection... */
if (is_fs_drawable)
- info->floating_sel_drawable = GIMP_DRAWABLE (layer_tqmask);
+ info->floating_sel_drawable = GIMP_DRAWABLE (layer_mask);
- return layer_tqmask;
+ return layer_mask;
error:
- g_object_unref (layer_tqmask);
+ g_object_unref (layer_mask);
return NULL;
}
diff --git a/filters/chalk/xcf/xcf/xcf-save.cc b/filters/chalk/xcf/xcf/xcf-save.cc
index c9043738..3544baf4 100644
--- a/filters/chalk/xcf/xcf/xcf-save.cc
+++ b/filters/chalk/xcf/xcf/xcf-save.cc
@@ -40,7 +40,7 @@
#include "core/gimpimage-guides.h"
#include "core/gimplayer.h"
#include "core/gimplayer-floating-sel.h"
-#include "core/gimplayertqmask.h"
+#include "core/gimplayermask.h"
#include "core/gimplist.h"
#include "core/gimpparasitelist.h"
#include "core/gimpunit.h"
@@ -293,7 +293,7 @@ xcf_save_image (XcfInfo *info,
nchannels = (TQ_UINT32) gimp_container_num_tqchildren (gimage->channels);
/* check and see if we have to save out the selection */
- have_selection = gimp_channel_bounds (gimp_image_get_tqmask (gimage),
+ have_selection = gimp_channel_bounds (gimp_image_get_mask (gimage),
&t1, &t2, &t3, &t4);
if (have_selection)
nchannels += 1;
@@ -365,7 +365,7 @@ xcf_save_image (XcfInfo *info,
}
else
{
- channel = gimage->selection_tqmask;
+ channel = gimage->selection_mask;
have_selection = FALSE;
}
@@ -506,14 +506,14 @@ xcf_save_layer_props (XcfInfo *info,
xcf_check_error (xcf_save_prop (info, gimage, PROP_LOCK_ALPHA,
error, layer->lock_alpha));
- if (layer->tqmask)
+ if (layer->mask)
{
xcf_check_error (xcf_save_prop (info, gimage, PROP_APPLY_MASK,
- error, layer->tqmask->apply_tqmask));
+ error, layer->mask->apply_mask));
xcf_check_error (xcf_save_prop (info, gimage, PROP_EDIT_MASK,
- error, layer->tqmask->edit_tqmask));
+ error, layer->mask->edit_mask));
xcf_check_error (xcf_save_prop (info, gimage, PROP_SHOW_MASK,
- error, layer->tqmask->show_tqmask));
+ error, layer->mask->show_mask));
}
else
{
@@ -575,7 +575,7 @@ xcf_save_channel_props (XcfInfo *info,
if (channel == gimp_image_get_active_channel (gimage))
xcf_check_error (xcf_save_prop (info, gimage, PROP_ACTIVE_CHANNEL, error));
- if (channel == gimage->selection_tqmask)
+ if (channel == gimage->selection_mask)
xcf_check_error (xcf_save_prop (info, gimage, PROP_SELECTION, error));
xcf_check_error (xcf_save_prop (info, gimage, PROP_OPACITY, error,
@@ -735,40 +735,40 @@ xcf_save_prop (XcfInfo *info,
case PROP_APPLY_MASK:
{
- TQ_INT32 apply_tqmask;
+ TQ_INT32 apply_mask;
- apply_tqmask = va_arg (args, TQ_INT32);
+ apply_mask = va_arg (args, TQ_INT32);
size = 4;
xcf_write_prop_type_check_error (info, prop_type);
xcf_write_int32_check_error (info, &size, 1);
- xcf_write_int32_check_error (info, &apply_tqmask, 1);
+ xcf_write_int32_check_error (info, &apply_mask, 1);
}
break;
case PROP_EDIT_MASK:
{
- TQ_INT32 edit_tqmask;
+ TQ_INT32 edit_mask;
- edit_tqmask = va_arg (args, TQ_INT32);
+ edit_mask = va_arg (args, TQ_INT32);
size = 4;
xcf_write_prop_type_check_error (info, prop_type);
xcf_write_int32_check_error (info, &size, 1);
- xcf_write_int32_check_error (info, &edit_tqmask, 1);
+ xcf_write_int32_check_error (info, &edit_mask, 1);
}
break;
case PROP_SHOW_MASK:
{
- TQ_INT32 show_tqmask;
+ TQ_INT32 show_mask;
- show_tqmask = va_arg (args, TQ_INT32);
+ show_mask = va_arg (args, TQ_INT32);
size = 4;
xcf_write_prop_type_check_error (info, prop_type);
xcf_write_int32_check_error (info, &size, 1);
- xcf_write_int32_check_error (info, &show_tqmask, 1);
+ xcf_write_int32_check_error (info, &show_mask, 1);
}
break;
@@ -1120,14 +1120,14 @@ xcf_save_layer (XcfInfo *info,
xcf_write_int32_check_error (info, &offset, 1);
saved_pos = info->cp;
- /* write out the layer tqmask */
- if (layer->tqmask)
+ /* write out the layer mask */
+ if (layer->mask)
{
xcf_check_error (xcf_seek_end (info, error));
offset = info->cp;
xcf_check_error (xcf_save_channel (info,
- gimage, GIMP_CHANNEL(layer->tqmask),
+ gimage, GIMP_CHANNEL(layer->mask),
error));
}
else